@@ -1,7 +1,7 @@
-
+\dontrun{
 demo_data # combiroc built-in demo data (proteomics data from Zingaretti et al. 2012 - PMC3518104)
 
 # To reshape demo_data in long format
 
 demo_data_long <- combiroc_long(data = demo_data)
-
+}
