@@ -1,6 +1,7 @@
+\dontrun{
 demo_data # combiroc built-in demo data (proteomics data from Zingaretti et al. 2012 - PMC3518104)
 
-combs <- combi(data= demo_data, signalthr=450, combithr=1)  # compute combinations
+combs <- combi(data= demo_data, signalthr=450, combithr=1, case_class='A')  # compute combinations
 
 
 # To train logistic regression models on each selected combinations and
@@ -14,3 +15,4 @@ reports$Plot  # Shows the ROC curves
 reports$Metrics # Shows the ROC metrics
 reports$Models # show models
 reports$reports$Models$`Combination 11` # show model trained with Combination 11
+}
\ No newline at end of file
